@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Array.pm
-## Version v1.5.2
+## Version v1.5.3
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2022/09/25
+## Modified 2022/10/17
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -33,7 +33,7 @@ BEGIN
     );
     $DEBUG  = 0;
     $RETURN = {};
-    our $VERSION = 'v1.5.2';
+    our $VERSION = 'v1.5.3';
 };
 
 use strict;
@@ -930,6 +930,14 @@ sub _scalar
 
 sub _warnings_is_enabled { CORE::return( warnings::enabled( ref( $_[0] ) || $_[0] ) ); }
 
+sub DESTROY
+{
+    my $self = shift( @_ );
+    my $id = Scalar::Util::refaddr( $self );
+    CORE:delete( $RETURN->{ $id } );
+    return( $self );
+}
+
 sub FREEZE
 {
     my $self = CORE::shift( @_ );
